pub struct ClientContext<'owner> { /* private fields */ }Expand description
An owned duckdb_client_context, borrow-tied to the owner it came from so it
cannot outlive it.
Implementations
Sourceimpl<'owner> ClientContext<'owner>
impl<'owner> ClientContext<'owner>
Sourcepub fn connection_id(&self) -> u64
pub fn connection_id(&self) -> u64
The stable connection id of the connection this context belongs to.